couchdb.schema.Field

Package couchdb :: Module schema :: Class Field |

# Class Field

    object --+
             |
            Field

Known Subclasses:
  - BooleanField
  - , DateField
  - , DateTimeField
  - , DecimalField
  - , DictField
  - , FloatField
  - , IntegerField
  - , ListField
  - , LongField
  - , TextField
  - , TimeField

Basic unit for mapping a piece of data between Python and JSON.

Instances of this class can be added to subclasses of Document to describe the schema of a document.

Instance Methods
__init__(self, name=None, default=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__get__(self, instance, owner) |
__set__(self, instance, value) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, name=None, default=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)